@@ -6,8 +6,8 @@ import importlib.metadata
 
 __all__ = [
     "memoize", "timer", "primes", "prime", "is_prime", "GCD", "LCM",
-    "DivisorSigma", "FactorInteger", "PrimeQ", "PrimePi", "pack", "fst", "snd", 
-    "Seq", "tco"
+    "DivisorSigma", "FactorInteger", "PrimeQ", "PrimePi", "pack", "fst", "snd",
+    "Seq", "tco", "List"
 ]
 
 
@@ -21,8 +21,5 @@ from .euler import memoize, timer, primes, prime, is_prime, GCD, LCM, \
 from .tco import tco
 
 
-from .Seq import pack, fst, snd
-
-
-from . import Seq
-
+from .seq import pack, fst, snd, Seq
+from .list import List
\ No newline at end of file
