@@ -61,6 +61,8 @@ def packed_function(function):
     """returns a function with a single input"""
     # needed in python 3.x since lambda functions are not automatically unpacked
     # as they were in python 2.7
+    if type(function) == _operator.itemgetter:
+        return function
     if function.__code__.co_argcount > 1:
         return pack(function)
     return function
